@@ -1,5 +1,6 @@
 package Pod::ProjectDocs::CSS;
 use strict;
+use warnings;
 use base qw/Pod::ProjectDocs::File/;
 use File::Basename;
 
@@ -7,11 +8,10 @@ __PACKAGE__->default_name('podstyle.css');
 __PACKAGE__->data( do{ local $/; <DATA> } );
 
 sub tag {
-	my $self = shift;
-	my $file = shift;
-	my($name, $path) = fileparse $file->path, qw/\.html/;
-	my $rel_path = File::Spec->abs2rel($self->path, $path);
-	return sprintf qq|<link rel="stylesheet" type="text/css" href="%s" />|, $rel_path;
+	my($self, $doc) = @_;
+	my($name, $path) = fileparse $doc->_get_output_path, qw/\.html/;
+	my $relpath = File::Spec->abs2rel($self->_get_output_path, $path);
+	return sprintf qq|<link rel="stylesheet" type="text/css" href="%s" />|, $relpath;
 }
 
 1;
